@@ -50,7 +50,7 @@ class BootstrapInfoDTO(BaseModel):
     cluster_config: ClusterConfigDTO
     template: str = 'normal'
     platform: str = 'aliyun'
-    patch_setting: Optional[Dict] = None
+    patch_setting: Optional[dict] = None
 
 
 
@@ -79,8 +79,8 @@ class APIGatewayRequestDTO(BaseModel):
     port: Optional[int] = None
     route: Optional[str] = None
     action: Optional[str] = None
-    auth: Optional[Dict] = None
-    data: Optional[Dict] = None
+    auth: Optional[dict] = None
+    data: Optional[dict] = None
 
 
 
