@@ -2,6 +2,7 @@ import datetime
 from typing import List, Optional, Dict, Tuple, Union
 from ..domain.entity import Entity
 from .value_obj import (
+    K3SNodeType,
     Status,
     UDate,
     UDict,
@@ -366,4 +367,61 @@ class TaskItem(Entity):
         self.details = details
         self.entry_time = entry_time
         self.exit_time = exit_time
-        self.exception = exception
\ No newline at end of file
+        self.exception = exception
+
+
+
+class NodeInventory(Entity):
+    def __init__(
+        self,
+        node_type: UStr,
+        amount: UInt,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.node_type = node_type
+        self.amount = amount
+
+
+
+class DNSInventory(Entity):
+    def __init__(
+        self,
+        domain: UStr,
+        subdomain: UStr,
+        node_type: Optional[K3SNodeType],
+        pod_name: Optional[UStr],
+        namespace_name: Optional[UStr],
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.domain = domain
+        self.subdomain = subdomain
+        self.node_type = node_type
+        self.pod_name = pod_name
+        self.namespace_name = namespace_name
+
+
+
+class RecoverSetting(Entity):
+    def __init__(
+        self,
+        node_inventory: Optional[List[NodeInventory]],
+        dns_inventory: Optional[List[DNSInventory]],
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.node_inventory = node_inventory
+        self.dns_inventory = dns_inventory
\ No newline at end of file
